﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Data;
using System.Windows.Documents;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Media3D;
using System.Windows.Media.Imaging;
using System.Windows.Navigation;
using System.Windows.Shapes;

namespace Articles.Tutorials.Wpf3D
{
    /// <summary>
    /// Interaktionslogik für Chapter1.xaml
    /// </summary>
    public partial class Chapter1 : UserControl
    {
        /// <summary>
        /// Initializes a new instance of the <see cref="Chapter1"/> class.
        /// </summary>
        public Chapter1()
        {
            InitializeComponent();

            //Register Loaded event. Thats where we build our simple model.
            this.Loaded += new RoutedEventHandler(OnLoaded);
        }

        /// <summary>
        /// Called when the window opens.
        /// </summary>
        /// <param name="sender">The sender.</param>
        /// <param name="e">The <see cref="System.Windows.RoutedEventArgs"/> instance containing the event data.</param>
        private void OnLoaded(object sender, RoutedEventArgs e)
        {
            //Create the mesh geometry
            MeshGeometry3D triangleMesh = new MeshGeometry3D();

            //Create all needex vertices
            triangleMesh.Positions.Add(new Point3D(-5, 0, -5));
            triangleMesh.Positions.Add(new Point3D(5, 0, 0));
            triangleMesh.Positions.Add(new Point3D(0, 0, 5));

            //Build the triangle
            triangleMesh.TriangleIndices.Add(0);
            triangleMesh.TriangleIndices.Add(2);
            triangleMesh.TriangleIndices.Add(1);

            //Set normals for all vertices
            Vector3D normal = new Vector3D(0, 1, 0);
            triangleMesh.Normals.Add(normal);
            triangleMesh.Normals.Add(normal);
            triangleMesh.Normals.Add(normal);

            //Build the model object
            Material material = new DiffuseMaterial(new SolidColorBrush(Colors.Blue));
            GeometryModel3D triangleModel = new GeometryModel3D(
                triangleMesh,
                material);

            //Build the visual object
            ModelVisual3D model = new ModelVisual3D();
            model.Content = triangleModel;

            //Add the object to the viewport
            this.m_viewport3D.Children.Add(model);
        }
    }
}
